@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "vhdl-ts-mode" "0.3.2"
+(define-package "vhdl-ts-mode" "20251008.2052"
   "VHDL Tree-sitter major mode."
   '((emacs "29.1"))
   :url "https://github.com/gmlarumbe/vhdl-ts-mode"
